bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 34. Aventiure
___________________________________________________ #### Wie si toten abe wurfen
| ### ie herren nach ir mvede gesazen do zetal ### Volker vn– Hagne die ien en fvr den sal ### sich leinden vber schilde die vbermveten man ### do wart da rede spehe von in beiden vil getan
###### 1947 | ### Do sprach von Bvrgonden Gyselher der degen ### ia mvget ir lieben vrivnde noch ruewe niht geplegen ### ir svlt die toten lvte vz dem hvse tragen ### wir werden noch bestanden ich wilz iv werlichen sagen
###### 1948 | ### Si svln vns vnder fvezen hie niht langer ligen ### e daz vns die Hvnen mit stvrme an gesigen ### wir howen noch die wunden div mir vil sanfte tvot ### des han ich sprach do Geyselher einen stetigen mvot
###### 1949 | ### So wol mich solhez herren sprach do Hagne ### der rat enzeme niemen wan eime degne ### den vns min ivnger herre hivte hat getan [79b] ### des mvget ir Burgonden alle vroelichen stan
###### 1950 | ### Do volgten si dem rate vn– trvogen fvr die tvr ### siben tvsent toten wurfen si der fvr ### vor des sales stiegen vieln si cetal ### do hvop sich von ir magen ein vil klagelicher schal
###### 1951 | ### Ez waz ir etlicher so mazlichen wunt ### der sin sanfter pflege er wurde noch gesvnt ### der von dem hohen valle mvoze ligen tot ### daz klagten al ir vriunde des gie in werlichen not
###### 1952 | ### Do sprach der videlere Volker ein helt gemeit ### nv kiuse ich des die warheit als mir ist geseit ### die Hvnen sint boese si klagent sam div wip ### si solden wan bervochen der vil sere wunden lip
###### 1953 | ### Do wand ein marcraue er reitez dvrch gvot ### er sach einen sinen mak gevallen in daz blvot ### er beslorin mit den armen vn– wold in tragen dan ### den schoz ob im ze tode der vil kvene spilman
###### 1954 | ### Do die andern daz <sahen> div flvht hvop sich von dan ### si begvnden alle vluochen dem selbem spilman ### einen ger er vf zvcte vil scharf vn– hart ### der von eime Hvenen zvo im dar vf geschozzen wart
###### 1955 | ### Den schoz er krefticlichen dvrch die burch dan ### vber daz volch verre den Eceln man ### gab er herberge hoher von dem sal ### sin vil starkez ellen die lvte vorhten vber al
###### 1956 | ### Do stvonden vor dem hvse manich tvsent man ### Volker vn– Hagne reden do began ### mit Eceln dem kvnige allen ir mvot ### des komen sit in sorge die helde kvene vn– gvot
###### 1957 | ### Ez zæme so sprach Hagne vil wol volker trost ### daz die herren vehten ze aller vorderost ### also der minen herren hie islicher tvot ### die howent dvrch die helme daz nach den swerten vlivzet blvot
###### 1958 | ### Ecel waz der kvene er vazte sinen schilt ### nv vart gewerlich sprach vrov Kriemhilt ### vn– bietet ir den reken daz golt vber rant ### wan erreichet ivch Hagne ir habet den tot an der hant
###### 1959 | ### Der kvnic waz so kvene er sold erwinden niht ### daz von so richen fursten selden nv geschiht ### man mvos in bi dem vezzel ziehen wider dan ### Hagne der grimme in aber hoenen began
###### 1960 | ### Ez was ein verre sippe sprach Hagne der degne ### wie Ecel vn– Sifrit zesamne hat gephlegen ### er minnete Kriemhilden e si ie gesæhe dich ### kvnich vil boese warvmbe ratest ane mich
###### 1961 | ### Dise rede horte des edeln kvniges wip ### des wart in vngemvete Kriemhilde lip ### daz er si torste schelden vor Ecelen man ### darvmbe si aber raten an die geste began [80a]
###### 1962 | ### Si sprach der von Trony Hagen slvege ### vn– mir sin hovbet her fvr mich trvoge ### dem svlt ich rotes goldes den Eceln rant ### dar zvo gebe ich im ze miete vil gvote bvrge vn– lant
###### 1963 | ### Nv enweiz ich wes si bitent sprach der spilman ### ine gesach nie helde me so zagelichen stan ### da man horte bieten also hohen solt ### ia ensold in Ecel darvmbe nimmer werden holt
###### 1964 | ### Die hie so lasterlichen ezzent des kvniges brot ### vn– im nv geswichent in der groezisten not ### der sihe ich hie manigen vil zaglichen stan ### vn– wellent doch sin kvene si mvezens immer schande han

<<< Übersicht <<< vorige Seite nächste Seite >>>